@@ -1,6 +1,6 @@
 package LLVM;
 {
-  $LLVM::VERSION = '0.02';
+  $LLVM::VERSION = '0.03';
 }
 
 use strict;
@@ -15,7 +15,7 @@ LLVM - Perl bindings to the Low Level Virtual Machine
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,19 @@ The output should look like this:
       ret i32 %tmp
     }
 
-Once the module is created, it can be compiled in-memory and executed:
+Once the module is created, a number of optimizations can be applied:
+
+    # create a new LLVM::PassManager
+    my $mgr = LLVM::PassManager -> new;
+
+    # schedule a couple of passes
+    $mgr -> function_inlining;
+    $mgr -> global_dce;
+
+    # run the pass manager on the module
+    $mgr -> run($mod);
+
+And finally the module can be compiled in-memory and executed:
 
     # create the arguments for the function call
     my $arg1 = LLVM::GenericValue -> int($intt, 5);
@@ -77,9 +89,11 @@ Once the module is created, it can be compiled in-memory and executed:
 
 The Low-Level Virtual Machine (LLVM) is a collection of libraries and tools
 that make it easy to build compilers, optimizers, Just-In-Time code generators,
-and many other compiler-related programs.
+and many other compiler-related programs. This module provides Perl bindings to
+the LLVM API.
 
-This module provides Perl bindings to the LLVM API.
+Note that this module is currently built and tested against LLVM v3.1, but
+chances are that it builds against older versions too.
 
 =head1 AUTHOR
 
